@@ -18,16 +18,16 @@
  *   Free Software Foundation, Inc.,                                       *
  *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.             *
  ***************************************************************************/
-#include <klocale.h>
-#include <kglobal.h>
+#include <tdelocale.h>
+#include <tdeglobal.h>
 #include <kiconloader.h>
-#include <kpopupmenu.h>
+#include <tdepopupmenu.h>
 #include <krun.h>
 #include <kurl.h>
 #include <kurldrag.h>
-#include <kmessagebox.h>
+#include <tdemessagebox.h>
 #include <kstdguiitem.h>
-#include <kfiledialog.h>
+#include <tdefiledialog.h>
 
 #include <interfaces/torrentinterface.h>
 #include <torrent/globals.h>
@@ -55,7 +55,7 @@ using namespace bt;
 using namespace kt;
 
 
-TorrentView::TorrentView(KTorrentView* parent) : KListView(parent),ktview(parent)
+TorrentView::TorrentView(KTorrentView* parent) : TDEListView(parent),ktview(parent)
 {}
 	
 TorrentView::~TorrentView() 
@@ -79,7 +79,7 @@ bool TorrentView::eventFilter(TQObject* watched, TQEvent* e)
 		}
 	}
 
-	return KListView::eventFilter(watched, e);
+	return TDEListView::eventFilter(watched, e);
 }
 
 KTorrentView::KTorrentView(TQWidget *parent)
@@ -99,8 +99,8 @@ KTorrentView::KTorrentView(TQWidget *parent)
 	connect(view,TQT_SIGNAL(currentChanged(TQListViewItem* )),
 			this,TQT_SLOT(onExecuted(TQListViewItem* )));
 	
-	connect(view,TQT_SIGNAL(contextMenu(KListView*, TQListViewItem*, const TQPoint& )),
-			this,TQT_SLOT(showContextMenu(KListView*, TQListViewItem*, const TQPoint& )));
+	connect(view,TQT_SIGNAL(contextMenu(TDEListView*, TQListViewItem*, const TQPoint& )),
+			this,TQT_SLOT(showContextMenu(TDEListView*, TQListViewItem*, const TQPoint& )));
 	
 	connect(view,TQT_SIGNAL(selectionChanged()),this,TQT_SLOT(onSelectionChanged()));
 
@@ -127,7 +127,7 @@ void KTorrentView::insertColumn(TQString label, TQt::AlignmentFlags align)
 void KTorrentView::setupColumns()
 {
 		//Header menu
-	m_headerMenu = new KPopupMenu(view);
+	m_headerMenu = new TDEPopupMenu(view);
 	m_headerMenu->setCheckable(true);
 	m_headerMenu->insertTitle(i18n("Visible columns"));
 	
@@ -206,7 +206,7 @@ void KTorrentView::setCurrentGroup(Group* group)
 	onExecuted(view->currentItem());
 }
 
-void KTorrentView::saveSettings(KConfig* cfg,int idx)
+void KTorrentView::saveSettings(TDEConfig* cfg,int idx)
 {
 	TQString group = TQString("KTorrentView-%1").arg(idx);
 	view->saveLayout(cfg,group);
@@ -215,7 +215,7 @@ void KTorrentView::saveSettings(KConfig* cfg,int idx)
 }
 
 
-void KTorrentView::loadSettings(KConfig* cfg,int idx)
+void KTorrentView::loadSettings(TDEConfig* cfg,int idx)
 {
 	TQString group = TQString("KTorrentView-%1").arg(idx);
 	view->restoreLayout(cfg,group);
@@ -461,7 +461,7 @@ void KTorrentView::onExecuted(TQListViewItem* item)
 	}
 }
 
-void KTorrentView::showContextMenu(KListView* ,TQListViewItem*,const TQPoint & p)
+void KTorrentView::showContextMenu(TDEListView* ,TQListViewItem*,const TQPoint & p)
 {
 	updateGroupsSubMenu(menu->getGroupsSubMenu());
 	menu->show(p);
