@@ -34,7 +34,7 @@ namespace RSS
 	 */
 	class DataRetriever : public TQObject
 	{
-		Q_OBJECT
+		TQ_OBJECT
   
 		public:
 			/**
@@ -89,7 +89,7 @@ namespace RSS
 	 */
 	class FileRetriever : public DataRetriever
 	{
-		Q_OBJECT
+		TQ_OBJECT
   
 		public:
 			/**
@@ -159,7 +159,7 @@ namespace RSS
 	 */
 	class OutputRetriever : public DataRetriever
 	{
-		Q_OBJECT
+		TQ_OBJECT
   
 		public:
 			/**
@@ -254,7 +254,7 @@ namespace RSS
 	 */
 	class Loader : public TQObject
 	{
-		Q_OBJECT
+		TQ_OBJECT
   
 		friend class someClassWhichDoesNotExist;
 		public:
@@ -340,4 +340,3 @@ namespace RSS
 }
 
 #endif // LIBRSS_LOADER_H
-// vim: noet:ts=4
